@@ -237,7 +237,7 @@ class WindowForecastIterator():
     def input_features(self) -> List[str]:
         """The list of the selected features for the input window"""
 
-        if not self.__input_features:
+        if self.__input_features is None:
             return self.features
         return self.__input_features
 
@@ -245,7 +245,7 @@ class WindowForecastIterator():
     def target_features(self) -> List[str]:
         """The list of the selected features for the target window"""
 
-        if not self.__target_features:
+        if self.__target_features is None:
             return self.features
         return self.__target_features
 
